@@ -1,53 +1,71 @@
 # The coef() methods in nlme and lme4 do something different,
 # other objects do not even have coef or vcov methods defined,
 # so we make a workaround by specifying our own generic methods:
-COEF          <- function( x, ... ) UseMethod("COEF")
-COEF.default  <- function( x, ... ) coef( x, ... )
-VCOV          <- function( x, ... ) UseMethod("VCOV")
-VCOV.default  <- function( x, ... ) vcov( x, complete=TRUE, ... )
+COEF          <- function(x, ...) UseMethod("COEF")
+COEF.default  <- function(x, ...) coef(x, ...)
+VCOV          <- function(x, ...) UseMethod("VCOV")
+VCOV.default  <- function(x, ...) vcov(x, complete = TRUE, ...)
 
 # Then we can get from these methods what we want from lme, mer etc.
-COEF.lme      <- function( x, ... ) nlme::fixed.effects( x )
-COEF.mer      <- function( x, ... ) lme4::fixef( x )
-COEF.lmerMod  <- function( x, ... ) lme4::fixef( x )
-# The vcov returns a matrix with the wrong class so we strip that:
-VCOV.lme      <- function( x, ... ) as.matrix(vcov( x ))
-VCOV.mer      <- function( x, ... ) as.matrix(vcov( x ))
-VCOV.lmerMod  <- function( x, ... ) as.matrix(vcov( x ))
+COEF.lme      <- function(x, ...) nlme::fixed.effects(x)
+COEF.mer      <- function(x, ...) lme4::fixef(x)
+COEF.lmerMod  <- function(x, ...) lme4::fixef(x)
+COEF.glmerMod <- function(x, ...) lme4::fixef(x)
 
-# For the rest of the non-conforming classes we then just need the methods not defined
-# VCOV.coxph    <- function( object, ... ) survival:A::vcov.coxph( object, complete=FALSE, ... )
-COEF.crr      <- function( object, ... ) object$coef
-VCOV.crr      <- function( object, ... ) object$var
-COEF.MIresult <- function( object, ... ) object$coefficients
-VCOV.MIresult <- function( object, ... ) object$variance
-COEF.mipo     <- function( object, ... ) object$qbar
-VCOV.mipo     <- function( object, ... ) object$t
-COEF.polr     <- function( object, ... ) summary(object)$coefficients
-VCOV.gnlm     <- function( object, ... ) object$cov
-VCOV.rq       <- function( object, ... ) summary(object, cov=TRUE)$cov
+# The vcov returns a matrix with the wrong class so we strip that:
+VCOV.lme      <- function(x, ...) as.matrix(vcov(x))
+VCOV.mer      <- function(x, ...) as.matrix(vcov(x))
+VCOV.lmerMod  <- function(x, ...) as.matrix(vcov(x))
+VCOV.glmerMod <- function(x, ...) as.matrix(vcov(x))
+
+# For the rest of the non-conforming classes we then just need the
+# methods not defined
+# VCOV.coxph    <- function(x, ...)
+#                  survival::vcov.coxph(x, complete=FALSE, ...)
+COEF.crr      <- function(x, ...) x$coef
+VCOV.crr      <- function(x, ...) x$var
+COEF.MIresult <- function(x, ...) x$coefficients
+VCOV.MIresult <- function(x, ...) x$variance
+COEF.mipo     <- function(x, ...) x$qbar
+VCOV.mipo     <- function(x, ...) x$t
+VCOV.gnlm     <- function(x, ...) x$cov
+VCOV.rq       <- function(x, ...) summary(x, cov=TRUE)$cov
 
 df2ctr <-
-function( obj, nd )
+function(obj, nd)
     {
-if( !( inherits(obj,"lm") | inherits(obj,"coxph") ) )
-  stop("data frame facility not inplemented for ", class(obj), " objects" )
+if (!(inherits(obj, "lm") | inherits(obj, "coxph")))
+  stop("data frame facility not inplemented for ", class(obj), " objects")
+
 # Factors in the prediction frame must have more than one level, which
-# they typically do not have in the specification, so we find the
-# factors in the prediction frame and expand levels to the complete
-# set of levels which should secure the working of model.matrix()
-dcl <- attr( obj$terms, "dataClasses" )
-whf <- ( dcl == "factor" )
-if( any(whf) ) for( fn in names(dcl)[which(whf)] )
-                nd[,fn] <- factor( nd[,fn], levels=obj$xlevels[[fn]] )
-# The contrast matrix from the model - differs a bit between (g)lm, gam and coxph
-# this is needed to keep NA rows from the data frame supplied
+# they typically do not have in the specification of a prediction
+# frame, so we find the factors in the prediction frame and expand
+# levels to the complete set of levels which we get from the model
+# object This should secure the working of model.matrix(); note that
+# the machinery differs between gam and non-gam glms
+
+dcl <- attr(obj$terms, "dataClasses")[-1] # the first is the reponse
+whf <- (dcl == "factor")
+if (any(whf))
+   {
+for (fn in names(dcl)[which(whf)])
+    {
+    nd[,fn] <- factor(nd[,fn],
+                      levels = if (inherits(obj, "gam"))
+                                  levels(obj$var.summary[[fn]])
+                             else        obj$xlevels    [[fn]])
+    }
+   }
+
+# The folowing is needed to keep NA rows from the data frame supplied
 org.op <- options( na.action='na.pass' )
 on.exit( options( org.op ) )
-if( inherits(obj,"coxph") ) MM <- model.matrix(         obj     ,    data=nd )
-if( inherits(obj,"gam"  ) ) MM <- model.matrix(         obj     , newdata=nd )
-    else
-if( inherits(obj,"lm"   ) ) MM <- model.matrix( formula(obj)[-2],    data=nd )
+
+# The contrast matrix from the model - differs a between (g)lm, gam and coxph
+if (inherits(obj,"coxph")) MM <- model.matrix(         obj     ,    data=nd)
+if (inherits(obj,"gam"  )) MM <- model.matrix(         obj     , newdata=nd)
+   else
+if (inherits(obj,"lm"   )) MM <- model.matrix( formula(obj)[-2],    data=nd)
 return( MM )
     }
 
@@ -60,24 +78,28 @@ function( obj, ndx, ndr,
         sample = FALSE )
 {
 if( nrow(ndr)==1 ) ndr <- ndr[rep(1,nrow(ndx)),,drop=FALSE]
-if( (    ( nrow(ndx) !=  nrow(ndr)) ) |
-    ( any(names(ndx) != names(ndr)) ) )
-    stop("\nThe two prediction frames must have same dimensions and column names:",
-         "but dimensions are: (",
-         paste( dim(ndx),collapse=","), ") and (",
-         paste( dim(ndr),collapse=","), ")\n", 
-         "and column names are:\n",
-         "exp: ", paste( names(ndx), collapse=", " ), "\n",
-         "ref: ", paste( names(ndr), collapse=", " ), "\n")
-# Now supply and fix those variables that are needed in order to get model.matrix working:
+if(         ( nrow(ndx)  !=       nrow(ndr)) |
+    any(sort(names(ndx)) != sort(names(ndr))) )
+    stop("\nThe two prediction frames must have same dimensions",
+         "and column names, but dimensions are (",
+         paste(dim(ndx), collapse=","), ") and (",
+         paste(dim(ndr), collapse=","), ")\n",
+         "and the column names are:\n",
+         "exp: ", paste(names(ndx), collapse=", "), "\n",
+         "ref: ", paste(names(ndr), collapse=", "), "\n")
+# Now supply and fix those variables that are needed in order to get
+# model.matrix working:
+
 # Supplied variable names:
  cols <- names( ndx )
-# Factors in model; which are supplied; derive names of omitted factors (ofacs)
+# Factors in model; which are supplied; derive names of omitted
+# factors (called ofacs)
  facs <- names( obj$xlevels )
 ofacs <- setdiff( facs, cols )
 # omitted *variables* must be supplied
 ovars <- setdiff( xvars, facs )
-# Construct the extra columns with bogus data (their contribution will be null)
+# Construct the extra columns with bogus data (their contribution will
+# be null)
 xcols <- ndx[,NULL]
 if( length(ofacs) > 0 ) for( fn in ofacs ) xcols[,fn] <- obj$xlevels[[fn]][1]
 if( length(ovars) > 0 ) for( vn in ovars ) xcols[,vn] <- 1
@@ -116,30 +138,33 @@ if( ( nrow(nd2) !=  nrow(nd1)) |
          paste( dim(nd1),collapse=","), ") and (",
          paste( dim(nd2),collapse=","), ") and (",
          paste( dim(nd3),collapse=","), ") and (",
-         paste( dim(nd4),collapse=","), ")\n", 
+         paste( dim(nd4),collapse=","), ")\n",
          "and column names are:\n",
          "1: ", paste( names(nd1), collapse=", " ), "\n",
          "2: ", paste( names(nd2), collapse=", " ), "\n",
          "3: ", paste( names(nd3), collapse=", " ), "\n",
          "4: ", paste( names(nd4), collapse=", " ), "\n")
-# Now supply and fix those variables that are needed in order to get model.matrix working:
+# Now supply and fix those variables that are needed in order to get
+# model.matrix working:
 # Supplied variable names:
  cols <- names( nd1 )
-# Factors in model; which are supplied; derive names of omitted factors (ofacs)
+# Factors in model; which are supplied; derive names of omitted
+# factors (ofacs)
  facs <- names( obj$xlevels )
 ofacs <- setdiff( facs, cols )
 # omitted *variables* must be supplied
 ovars <- setdiff( xvars, facs )
-# Construct the extra columns with bogus data (their contribution will be null)
+# Construct the extra columns with bogus data (their contribution will
+# be null)
 xcols <- nd1[,NULL]
 if( length(ofacs) > 0 ) for( fn in ofacs ) xcols[,fn] <- obj$xlevels[[fn]][1]
 if( length(ovars) > 0 ) for( vn in ovars ) xcols[,vn] <- 1
 if( dim(xcols)[2]>0 )
   {
   nd1 <- cbind( nd1, xcols )
-  nd2 <- cbind( nd2, xcols ) 
+  nd2 <- cbind( nd2, xcols )
   nd3 <- cbind( nd3, xcols )
-  nd4 <- cbind( nd4, xcols ) 
+  nd4 <- cbind( nd4, xcols )
   }
 ci.lin( obj,
     ctr.mat = df2ctr( obj, nd1 )
@@ -166,14 +191,14 @@ function( obj,
           Exp = FALSE,
        sample = FALSE )
 {
-# If ctr.mat is a data frame, call df2ctr 
+# If ctr.mat is a data frame, call df2ctr
 if( inherits( ctr.mat, "data.frame" ) ) ctr.mat <- df2ctr( obj, ctr.mat )
 
 # If ctr.mat is a list of two dataframes then call ci.dfr
 if( inherits( ctr.mat, "list" ) )
   {
   if( length(ctr.mat)==2 )
-    {  
+    {
   if( !inherits( ctr.mat[[1]], "data.frame" ) |
       !inherits( ctr.mat[[2]], "data.frame" ) )
       stop("If ctr.mat is a list it must be a list of data frames")
@@ -187,7 +212,7 @@ if( inherits( ctr.mat, "list" ) )
 # If ctr.mat is a list of two dataframes then call ci.dfr2 for 2nd
 # order differences
   if( length(ctr.mat)==4 )
-    {  
+    {
   if( !inherits( ctr.mat[[1]], "data.frame" ) |
       !inherits( ctr.mat[[2]], "data.frame" ) |
       !inherits( ctr.mat[[3]], "data.frame" ) |
@@ -248,7 +273,7 @@ cm[cbind(1:nr,ctr[,2])] <- -1
 rownames( cm ) <- rn
 cm
 }
-# end of the function all.dif for all differences 
+# end of the function all.dif for all differences
 
 # Were all differences requested?
 if( diffs )
@@ -318,10 +343,10 @@ if( !diffs )
   if( sample )
     {
     # mvrnorm() returns a vector if sample=1, otherwise a sample by
-    # length(cf) matrix - hence the rbind so we always get a row 
+    # length(cf) matrix - hence the rbind so we always get a row
     # matrix and res then becomes an nrow(ctr.mat) by sample matrix
-    res <- ctr.mat %*% t( rbind(mvrnorm( sample, cf, vcv )) )   
-    }  
+    res <- ctr.mat %*% t( rbind(mvrnorm( sample, cf, vcv )) )
+    }
   else
     {
     ct <- ctr.mat %*% cf
@@ -355,7 +380,7 @@ if( vcov ) invisible( list( coef=ct[,1], vcov=vc ) ) else res
 ci.exp <-
 function( ..., Exp=TRUE, pval=FALSE )
 {
-res <- if( Exp ) 
+res <- if( Exp )
          {
 ci.lin( ..., Exp=TRUE  )[,if(pval) c(5:7,4)   else 5:7     ,drop=FALSE]
          } else {
@@ -381,7 +406,7 @@ zz <- predict( obj, newdata=newdata, se.fit=TRUE, type="link" )
 zz <- cbind( zz$fit, zz$se.fit ) %*% ci.mat( alpha=alpha )
 # transform as requested
 if( missing(Exp) ) {   return( obj$family$linkinv(zz) )
-} else {  if(  Exp ) { return(                exp(zz) ) 
+} else {  if(  Exp ) { return(                exp(zz) )
    } else if( !Exp )   return(                    zz  )
        }
      }
@@ -409,17 +434,17 @@ if( is.matrix(r2) ) if( ncol(r2)==1 ) r2 <- as.vector( r2 )
 
 # move to log scale
 if( !log.tr ) {
-  r1 <- log( r1 ) 
-  r2 <- log( r2 ) 
+  r1 <- log( r1 )
+  r2 <- log( r2 )
   }
 
-# how wide are the condidence intervals    
+# how wide are the condidence intervals
 if( is.matrix(r1) ) if( ncol(r1)>1 ) rg1 <- t( apply(r1,1,range) )
 if( is.matrix(r2) ) if( ncol(r2)>1 ) rg2 <- t( apply(r2,1,range) )
 
 # get the estimates on the log-scale
-R1 <- if( is.matrix(r1) ) apply( rg1, 1, mean ) else r1 
-R2 <- if( is.matrix(r2) ) apply( rg2, 1, mean ) else r2 
+R1 <- if( is.matrix(r1) ) apply( rg1, 1, mean ) else r1
+R2 <- if( is.matrix(r2) ) apply( rg2, 1, mean ) else r2
 if( is.null(se1) ) se1 <- apply( rg1, 1, diff ) / (2*qnorm(1-alpha/2))
 if( is.null(se2) ) se2 <- apply( rg2, 1, diff ) / (2*qnorm(1-alpha/2))
 
@@ -429,5 +454,5 @@ slrr <- sqrt( se1^2 + se2^2 )
   rr <- cbind(lrr,slrr) %*% ci.mat(alpha=alpha)
 if( !log.tr ) rr <- exp( rr )
 if( pval ) return( cbind( rr, 1-pchisq( (lrr/slrr)^2, 1 ) ) )
-      else return(        rr                                )    
+      else return(        rr                                )
 }
