@@ -54,7 +54,7 @@ if( missing(xlog) ) xlog <- mult
  # sufficient place can be made for the text in the margin
  #
 plot.new()
-mx <- max( strwidth( unlist( strsplit( txt, "\n" ) ), units="in" ) )
+mx <- max( strwidth( txt, units="in" ) )
 oldpar <- par( mai=par("mai") + c(0,mx,0,0) )
 if( restore.par ) on.exit( par( oldpar ) )
 
@@ -78,9 +78,9 @@ linesEst( ests, y, pch=pch, cex=cex, lwd=lwd,
 
  # Finally the x-axis and the annotation of the estimates
  #
-axis( side = 1, at = xtic )
+axis( side=1, at=xtic )
 mtext( side=1, xlab, line=par("mgp")[1], cex=par("cex")*par("cex.lab") )
-axis( side=2, at=txtpos, labels=txt, las=2, lty=0, col=col.txt )
+axis( side=2, at=txtpos, labels=txt, las=1, lty=0, col.axis=col.txt )
 invisible( oldpar )
   }
 
@@ -119,24 +119,23 @@ invisible()
 }
 
 nice <-
-function( x,
-        log = F,
-       lpos = c(1,2,5), ... )
+function (x, log = FALSE, lpos = c(1, 2, 5), xmx = 4, ...)
 {
-# Function to produce nice labels also for log-axes.
-#
-if( log )
-  {
-  fc <- floor( log10( min( x ) ) ):ceiling( log10( max( x ) ) )
-  tick <- as.vector( outer( lpos, 10^fc, "*" ) )
-  ft <- max( tick[tick<min(x)] )
-  lt <- min( tick[tick>max(x)] )
-  tick <- tick[tick>=ft & tick<=lt]
-  if( length( tick ) < 4 & missing( lpos ) )
-    tick <- nice( x, log=T, lpos=c(1:9) )
-  if( length( tick ) > 10 & missing( lpos ) )
-    tick <- nice( x, log=T, lpos=1 )
-  tick
-  }
-else pretty( x, ... )
+if (log)
+   {
+   # not too extreme limits on log-scale
+   fc <- floor(max(log10(min(x)), .1^xmx)):
+       ceiling(min(log10(max(x)), 10^xmx))
+   tick <- as.vector(outer(lpos, 10^fc, "*"))
+   ft <- max(tick[tick < min(x)])
+   lt <- min(tick[tick > max(x)])
+   tick <- tick[tick >= ft & tick <= lt]
+   if (length(tick) < 4 & missing(lpos))
+      tick <- nice(x, log = T, lpos = c(1:9))
+   if (length(tick) > 10 & missing(lpos))
+      tick <- nice(x, log = T, lpos = 1)
+   tick
+   } else {
+pretty(x, ...)
+}
 }
