@@ -1,17 +1,29 @@
 ### R code from vignette source 'addLexis.rnw'
 
 ###################################################
-### code chunk number 1: addLexis.rnw:20-25
+### code chunk number 1: addLexis.rnw:20-31
 ###################################################
-options( width=90,
-         SweaveHooks=list( fig=function()
-         par(mar=c(3,3,1,1),mgp=c(3,1,0)/1.6,las=1,bty="n") ) )
+options(width = 90,
+        SweaveHooks = list(fig = function()
+        par(mar = c(3,3,1,1),
+            mgp = c(3,1,0) / 1.6,
+            las = 1,
+           lend = "butt",
+            bty = "n")))
 library(Epi)
+library(popEpi)
 library(dplyr)
+library(tidyr)
 
 
 ###################################################
-### code chunk number 2: addLexis.rnw:92-104
+### code chunk number 2: addLexis.rnw:35-36
+###################################################
+anfang <- Sys.time()
+
+
+###################################################
+### code chunk number 3: addLexis.rnw:104-116
 ###################################################
 xcoh <- structure(list(id = c("A", "B", "C"),
                     birth = c("1952-07-14", "1954-04-01", "1987-06-10"),
@@ -28,10 +40,10 @@ xcoh
 
 
 ###################################################
-### code chunk number 3: addLexis.rnw:111-119
+### code chunk number 4: addLexis.rnw:123-131
 ###################################################
 Lcoh <- Lexis(entry = list(per = doe),
-               exit = list(per = dox, 
+               exit = list(per = dox,
                            age = dox - dob),
                  id = id,
         exit.status = factor(fail, 0:1, c("Alive","Dead")),
@@ -41,7 +53,7 @@ str(Lcoh)
 
 
 ###################################################
-### code chunk number 4: addLexis.rnw:135-138
+### code chunk number 5: addLexis.rnw:147-150
 ###################################################
 Lx$lex.id <- as.character(Lx$lex.id)
 str(Lx)
@@ -49,13 +61,13 @@ Lx
 
 
 ###################################################
-### code chunk number 5: addLexis.rnw:146-158
+### code chunk number 6: addLexis.rnw:158-170
 ###################################################
 clin <- data.frame(lex.id = c("A", "A", "C", "B", "C"),
-                      per = cal.yr(c("1977-3-17", 
-                                     "1973-7-29", 
-                                     "1996-3-1", 
-                                     "1990-7-14", 
+                      per = cal.yr(c("1977-3-17",
+                                     "1973-7-29",
+                                     "1996-3-1",
+                                     "1990-7-14",
                                      "1989-1-31")),
                        bp = c(120, 140, 160, 157, 145),
                      chol = c(NA, 5, 8, 9, 6),
@@ -66,20 +78,20 @@ clin
 
 
 ###################################################
-### code chunk number 6: addLexis.rnw:169-170
+### code chunk number 7: addLexis.rnw:184-185
 ###################################################
 (Cx <- addCov.Lexis(Lx, clin))
 
 
 ###################################################
-### code chunk number 7: addLexis.rnw:184-186
+### code chunk number 8: addLexis.rnw:199-201
 ###################################################
 (Dx <- addCov.Lexis(Lx, clin, exnam = "xnam", tfc = "tfCl"))
 summary(Dx, t=T)
 
 
 ###################################################
-### code chunk number 8: addLexis.rnw:193-208
+### code chunk number 9: addLexis.rnw:208-223
 ###################################################
 # split BEFORE add
 Lb <- addCov.Lexis(splitLexis(Lx,
@@ -99,7 +111,7 @@ La
 
 
 ###################################################
-### code chunk number 9: addLexis.rnw:214-217
+### code chunk number 10: addLexis.rnw:229-232
 ###################################################
 La$tfc == Lb$tfc
 La$age == Lb$age
@@ -107,52 +119,46 @@ La$per == Lb$per
 
 
 ###################################################
-### code chunk number 10: addLexis.rnw:220-234
+### code chunk number 11: addLexis.rnw:235-247
 ###################################################
-if (require(popEpi, quietly=TRUE)) {
-    ## split BEFORE add
-    Mb <- addCov.Lexis(splitMulti(Lx, age = seq(0, 80, 5)),
-                       clin,
-                       exnam = "xnam" )
-    ##
-    ## split AFTER add
-    Ma <- splitMulti(addCov.Lexis(Lx,
-                                  clin,
-                                  exnam = "xnam" ),
-                     age = seq(0, 80, 5))
-    La$tfc == Mb$tfc
-    Ma$tfc == Mb$tfc
-}
+## split BEFORE add
+Mb <- addCov.Lexis(splitMulti(Lx, age = seq(0, 80, 5)),
+                   clin,
+                   exnam = "xnam" )
+##
+## split AFTER add
+Ma <- splitMulti(addCov.Lexis(Lx,
+                              clin,
+                              exnam = "xnam" ),
+                 age = seq(0, 80, 5))
+La$tfc == Mb$tfc
+Ma$tfc == Mb$tfc
 
 
 ###################################################
-### code chunk number 11: addLexis.rnw:249-257
+### code chunk number 12: addLexis.rnw:262-268
 ###################################################
-if (require(tidyr, quietly=TRUE)) {
-    cov <- c("bp", "chol")
-    Lx <- La
-    Lx <- group_by(Lx, lex.id) %>% 
-        fill(all_of(cov)) %>% 
-        ungroup()
-    class(Lx)
-}
+cov <- c("bp", "chol")
+Lx <- La
+Lx <- group_by(Lx, lex.id) %>%
+         fill(all_of(cov)) %>%
+      ungroup()
+class(Lx)
 
 
 ###################################################
-### code chunk number 12: addLexis.rnw:262-270
+### code chunk number 13: addLexis.rnw:273-279
 ###################################################
-if (require(tidyr, quietly=TRUE)) {
-    Lx <- La
-    Lx[,cov] <- as.data.frame( group_by(Lx, lex.id) 
-                              %>% fill(all_of(cov)))[,cov]
-    class(Lx)
-    La
-    Lx
-}
+Lx <- La
+Lx[,cov] <- as.data.frame(group_by(Lx, lex.id)
+                          %>% fill(all_of(cov)))[,cov]
+class(Lx)
+La
+Lx
 
 
 ###################################################
-### code chunk number 13: addLexis.rnw:338-351
+### code chunk number 14: addLexis.rnw:347-360
 ###################################################
 fu <- data.frame(doe = c(2006, 2008),
                  dox = c(2015, 2018),
@@ -170,7 +176,7 @@ str(Sx)
 
 
 ###################################################
-### code chunk number 14: addLexis.rnw:360-370
+### code chunk number 15: addLexis.rnw:369-379
 ###################################################
 set.seed(1952)
 rf <- data.frame(per = c(2005 + runif(12, 0, 10)),
@@ -185,7 +191,7 @@ rg <- data.frame(per = c(2009 + runif(10, 0, 10)),
 
 
 ###################################################
-### code chunk number 15: addLexis.rnw:381-384
+### code chunk number 16: addLexis.rnw:391-394
 ###################################################
 pdat <- list(F = rf, G = rg)
 pdat
@@ -193,25 +199,25 @@ Lx
 
 
 ###################################################
-### code chunk number 16: addLexis.rnw:393-406
+### code chunk number 17: addLexis.rnw:403-416
 ###################################################
 summary(Sx) ; names(Sx)
 ex1 <- addDrug.Lexis(Sx, pdat, method = "ext") # default
 summary(ex1) ; names(ex1)
-ex1
+print(ex1, nd = 2)
 ex2 <- addDrug.Lexis(Sx, pdat, method = "ext", grace = 0.5)
 summary(ex2)
-ex2
+print(ex2, nd = 2)
 dos <- addDrug.Lexis(Sx, pdat, method = "dos", dpt = 6)
 summary(dos)
-dos
+print(dos, nd = 2)
 fix <- addDrug.Lexis(Sx, pdat, method = "fix", maxt = 1)
 summary(fix)
-fix
+print(fix, nd = 2)
 
 
 ###################################################
-### code chunk number 17: addLexis.rnw:415-424
+### code chunk number 18: addLexis.rnw:425-434
 ###################################################
 data(DMlate) ; str(DMlate)
 Lx <- Lexis(entry = list(per = dodm,
@@ -220,67 +226,68 @@ Lx <- Lexis(entry = list(per = dodm,
              exit = list(per = dox),
       exit.status = factor(!is.na(dodth),
                            labels = c("DM", "Dead")),
-             data = DMlate)
+             data = DMlate[sample(1:nrow(DMlate), 1000),])
 summary(Lx)
 
 
 ###################################################
-### code chunk number 18: addLexis.rnw:428-430
+### code chunk number 19: addLexis.rnw:438-441
 ###################################################
 Sx <- splitLexis(Lx[,1:7], time.scale="age", breaks = 0:120)
 summary(Sx)
+str(Sx)
 
 
 ###################################################
-### code chunk number 19: addLexis.rnw:438-479
+### code chunk number 20: addLexis.rnw:449-490
 ###################################################
 set.seed(1952)
 
 purA <-
-  ( data.frame(lex.id = rep(Lx$lex.id, 
+  ( data.frame(lex.id = rep(Lx$lex.id,
                             round(runif(nrow(Lx), 0, 20))))
 %>% left_join(Lx[,c("lex.id", "dodm", "dox")])
 %>% mutate(per = dodm + runif(length(dodm), -0.1, 0.99) * (dox - dodm),
            amt = sample(4:20*10, length(dodm), replace = TRUE),
            dpt = amt * round(runif(length(dodm), 3, 7)))
 %>% select(-dodm, -dox)
-%>% arrange(lex.id, per)            
+%>% arrange(lex.id, per)
   )
-addmargins(table(table(purA$lex.id)))      
+addmargins(table(table(purA$lex.id)))
 str(purA)
 
 purB <-
-  ( data.frame(lex.id = rep(Lx$lex.id, 
+  ( data.frame(lex.id = rep(Lx$lex.id,
                             round(pmax(runif(nrow(Lx), -10, 15), 0))))
 %>% left_join(Lx[,c("lex.id", "dodm", "dox")])
 %>% mutate(per = dodm + runif(length(dodm), -0.1, 0.99) * (dox - dodm),
            amt = sample(4:20*10, length(dodm), replace = TRUE),
            dpt = amt * round(runif(length(dodm), 5, 9)))
 %>% select(-dodm, -dox)
-%>% arrange(lex.id, per) 
-  ) -> purB      
-addmargins(table(table(purB$lex.id)))      
+%>% arrange(lex.id, per)
+  ) -> purB
+addmargins(table(table(purB$lex.id)))
 str(purB)
 
 purC <-
-  ( data.frame(lex.id = rep(Lx$lex.id, 
+  ( data.frame(lex.id = rep(Lx$lex.id,
                             round(pmax(runif(nrow(Lx), -5, 12), 0))))
 %>% left_join(Lx[,c("lex.id", "dodm", "dox")])
 %>% mutate(per = dodm + runif(length(dodm), -0.1, 0.99) * (dox - dodm),
            amt = sample(4:20*10, length(dodm), replace = TRUE),
            dpt = amt * round(runif(length(dodm), 5, 7)))
 %>% select(-dodm, -dox)
-%>% arrange(lex.id, per) 
-  ) 
-addmargins(table(table(purB$lex.id)))      
+%>% arrange(lex.id, per)
+  )
+addmargins(table(table(purC$lex.id)))
 str(purC)
 head(purC)
 
 
 ###################################################
-### code chunk number 20: addLexis.rnw:494-501
+### code chunk number 21: addLexis.rnw:505-512
 ###################################################
-Sx1 <- subset(Sx, lex.id < 1000)
+Sx1 <- subset(Sx, lex.id < 100)
 pur <- list(A = subset(purA, lex.id < 1000),
             B = subset(purB, lex.id < 1000),
             C = subset(purC, lex.id < 1000))
@@ -290,7 +297,7 @@ summary(ad1)
 
 
 ###################################################
-### code chunk number 21: addLexis.rnw:504-511
+### code chunk number 22: addLexis.rnw:516-523
 ###################################################
 Sx2 <- subset(Sx, lex.id < 500)
 pur <- list(A = subset(purA, lex.id < 500),
@@ -302,36 +309,36 @@ summary(ad2)
 
 
 ###################################################
-### code chunk number 22: addLexis.rnw:518-525
+### code chunk number 23: addLexis.rnw:530-537
 ###################################################
-pur <- list(A = subset(purA, lex.id < 500 & runif(nrow(purA)) < 0.5),
-            B = subset(purB, lex.id < 500 & runif(nrow(purB)) < 0.5),
-            C = subset(purC, lex.id < 500 & runif(nrow(purC)) < 0.5))
+pur <- list(A = subset(purA, lex.id < 100 & runif(nrow(purA)) < 0.5),
+            B = subset(purB, lex.id < 100 & runif(nrow(purB)) < 0.5),
+            C = subset(purC, lex.id < 100 & runif(nrow(purC)) < 0.5))
 sapply(pur, nrow)
-system.time(ad3 <- addDrug.Lexis(Sx2, pur, tnam = "per", grace = 1/6))
-summary(Sx2)
+system.time(ad3 <- addDrug.Lexis(Sx1, pur, tnam = "per", grace = 1/6))
+summary(Sx1)
 summary(ad3)
 
 
 ###################################################
-### code chunk number 23: addLexis.rnw:541-547
+### code chunk number 24: addLexis.rnw:553-559
 ###################################################
-pur <- list(B = subset(purB, lex.id < 500),
-            C = subset(purC, lex.id < 500))
+pur <- list(B = subset(purB, lex.id < 100),
+            C = subset(purC, lex.id < 100))
 sapply(pur, nrow)
-system.time(ad4 <- addDrug.Lexis(Sx2, pur, tnam = "per", grace = 1/6))
-summary(Sx2)
+system.time(ad4 <- addDrug.Lexis(Sx1, pur, tnam = "per", grace = 1/6))
+summary(Sx1)
 summary(ad4)
 
 
 ###################################################
-### code chunk number 24: addLexis.rnw:556-557
+### code chunk number 25: addLexis.rnw:568-569
 ###################################################
 summary(ad1$lex.dur)
 
 
 ###################################################
-### code chunk number 25: addLexis.rnw:574-577
+### code chunk number 26: addLexis.rnw:586-589
 ###################################################
 summary(ad1)
 summary(adc <- coarse.Lexis(ad1, lim = c(1/6,1/2)))
@@ -339,28 +346,37 @@ summary(adc$lex.dur)
 
 
 ###################################################
-### code chunk number 26: addLexis.rnw:590-600
+### code chunk number 27: addLexis.rnw:602-612
 ###################################################
 summary(Sx2)
-system.time(ad4 <- addDrug.Lexis(Sx2, 
-                                 pur, 
+system.time(ad4 <- addDrug.Lexis(Sx2,
+                                 pur,
                                 tnam = "per",
                                grace = 1/6))
 summary(ad4)
 #
-ad5 <- coarse.Lexis(ad4, 
+ad5 <- coarse.Lexis(ad4,
                     lim = c(1/4, 1/2))
 summary(ad5)
 
 
 ###################################################
-### code chunk number 27: addLexis.rnw:605-611
+### code chunk number 28: addLexis.rnw:617-623
 ###################################################
 ad4$keep <- with(ad4, (B.ex & B.ct == 0) |
                       (C.ex & C.ct == 0))
-ad6 <- coarse.Lexis(ad4, 
+ad6 <- coarse.Lexis(ad4,
                     lim = c(1/4, 1/2),
                    keep = ad4$keep)
 summary(ad6)
 
 
+###################################################
+### code chunk number 29: addLexis.rnw:652-656
+###################################################
+ende <- Sys.time()
+cat("  Start time:", format(anfang, "%F, %T"),
+  "\n    End time:", format(  ende, "%F, %T"),
+  "\nElapsed time:", round(difftime(ende, anfang, units = "mins"), 2), "minutes\n")
+
+
